@@ -15,7 +15,8 @@ def plot_wikipedia_pmfs():
     for r in r_s:
         ax = axes.flat[r_s.index(r)]
         NegativeBinomial(r=r, p=0.5).with_label(f'r = {r}').plot(
-            k=k_wiki, kind='line', color='blue', ax=ax, ls='-', marker='o', vlines=True
+            k=k_wiki, kind='line', color='blue', ax=ax,
+            ls='-', marker='o', vlines=True
         )
         ax.set_ylim(0, 0.12)
         ax.legend(loc='upper right')
