@@ -6,7 +6,7 @@ from scipy.stats import t, rv_continuous
 from probability.custom_types.external_custom_types import Array1d
 from probability.custom_types.compound_types import RVMixin
 from probability.distributions.continuous.gamma import Gamma
-from probability.distributions.continuous.inv_gamma import InvGamma
+from probability.distributions.continuous.inverse_gamma import InverseGamma
 from probability.distributions.mixins.conjugate import ConjugateMixin
 from probability.utils import num_format
 
@@ -77,7 +77,7 @@ class _GammaNormalConjugate(ConjugateMixin, object):
         self._reset_distribution()
 
     def prior(self) -> Gamma:
-        return InvGamma(
+        return InverseGamma(
             alpha=self._alpha, beta=self._beta
         ).with_x_label('τ').prepend_to_label('Prior: ')
 
